Changelog
=========


1.0.2 (2024-11-20)
------------------

- Add NewsItem summary serializer, to return always metadata infos about tipologia_notizia and tipologia_notizia_metadata.
  [cekk]


1.0.1 (2024-11-19)
------------------

- Fix package name.
  [daniele]


1.0.0 (2024-11-19)
------------------

- Initial release.
  [daniele]
